django-nonprofit
================


Settings
--------

NONPROFIT_NAME
    'Sunlight Foundation'

NONPROFIT_URL_DISPLAY
    'SunlightFoundation.com'

NONPROFIT_EMAIL
    'contact@sunlightfoundation.com'

NONPROFIT_FUNDING_DOWNLOAD
    False
